@@ -49,7 +49,7 @@
 
 base_map <- function(bbox, bg_crs = 4326,
                      vector_only = FALSE,
-                     maptype = maptype,
+                     maptype = "stamen_toner_lite",
                      zoom = NULL,
                      ... ) {
 
