@@ -229,7 +229,7 @@ seasonal_dot.swmpr <- function(swmpr_in
             panel.border = element_rect(color = 'black')) +
       theme(axis.text.x = element_text(angle = 90, vjust = 0.5),
             axis.title.y = element_text(margin = unit(c(0, 8, 0, 0), 'pt'), angle = 90)) +
-      theme(text = element_text(size = 16))
+      theme(text = element_text(size = 14)) # was 16
 
     # Adjust legend keys and spacing
     plt <-
