@@ -317,7 +317,7 @@ threshold_percentile_plot.swmpr <- function(swmpr_in
           panel.border = element_rect(color = 'black')) +
     theme(plot.margin = margin(5.5, 11, 11, 5.5, 'pt')) +
     theme(axis.title.y = element_text(margin = margin(0, 8, 0, 0, 'pt'), angle = 90)) + #trbl
-    theme(text = element_text(size = 16))
+    theme(text = element_text(size = 14)) # was 16
 
   # Adjust legend keys and spacing
   plt <-
